@@ -14,8 +14,8 @@ class BaseExtControl(ExtUIComponent):
     def __init__(self, *args, **kwargs):
         super(BaseExtControl, self).__init__(*args, **kwargs)
 
-    def make_read_only(
-            self, access_off=True, exclude_list=[], *args, **kwargs):
+    def _make_read_only(
+            self, access_off=True, exclude_list=(), *args, **kwargs):
         # TODO: Нахера тут переопределение, если в базовом классе тоже самое?
         # Описание в базовом классе ExtUiComponent.
         raise NotImplementedError()
